@@ -16,6 +16,10 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+#if !defined (__GLIB_GOBJECT_H_INSIDE__) && !defined (GOBJECT_COMPILATION)
+#error "Only <glib-object.h> can be included directly."
+#endif
+
 #ifndef __G_BOXED_H__
 #define __G_BOXED_H__
 
@@ -39,9 +43,9 @@ gpointer	g_boxed_copy			(GType		 boxed_type,
 void		g_boxed_free			(GType		 boxed_type,
 						 gpointer	 boxed);
 void		g_value_set_boxed		(GValue		*value,
-						 gconstpointer	 boxed);
+						 gconstpointer	 v_boxed);
 void		g_value_set_static_boxed	(GValue		*value,
-						 gconstpointer	 boxed);
+						 gconstpointer	 v_boxed);
 gpointer	g_value_get_boxed		(const GValue	*value);
 gpointer	g_value_dup_boxed		(const GValue	*value);
 
@@ -52,12 +56,32 @@ GType	g_boxed_type_register_static		(const gchar	*name,
 						 GBoxedFreeFunc	 boxed_free);
 
 
-/* --- marshaller specific --- */
+/* --- GLib boxed types --- */
+#define	G_TYPE_CLOSURE		(g_closure_get_type ())
+#define	G_TYPE_VALUE		(g_value_get_type ())
+#define	G_TYPE_VALUE_ARRAY	(g_value_array_get_type ())
+#define	G_TYPE_DATE	        (g_date_get_type ())
+#define	G_TYPE_STRV	        (g_strv_get_type ())
+#define	G_TYPE_GSTRING		(g_gstring_get_type ())
+#define	G_TYPE_HASH_TABLE	(g_hash_table_get_type ())
+
+
+void    g_value_take_boxed      (GValue		*value,
+				 gconstpointer	 v_boxed);
+#ifndef G_DISABLE_DEPRECATED
 void	g_value_set_boxed_take_ownership	(GValue		*value,
-						 gconstpointer	 boxed);
-
-
+						 gconstpointer	 v_boxed);
+#endif
+GType	g_closure_get_type	(void)	G_GNUC_CONST;
+GType	g_value_get_type	(void)	G_GNUC_CONST;
+GType	g_value_array_get_type	(void)	G_GNUC_CONST;
+GType	g_date_get_type	        (void)	G_GNUC_CONST;
+GType	g_strv_get_type	        (void)	G_GNUC_CONST;
+GType	g_gstring_get_type      (void)	G_GNUC_CONST;
+GType   g_hash_table_get_type   (void)  G_GNUC_CONST;
 
+typedef gchar** GStrv;
+     
 G_END_DECLS
 
 #endif	/* __G_BOXED_H__ */
